@@ -4,10 +4,14 @@ from typing import Dict, List, Optional
 
 import h5py
 import numpy as np
+import plotly.graph_objects as go
 from astromodels import TemplateModel, TemplateModelFactory
 from astromodels.utils.logging import silence_console_log
 from tqdm.auto import tqdm
 
+from ronswanson.grids import Parameter, ParameterGrid
+from ronswanson.utils.color import Colors
+
 from .utils.logging import setup_logger
 
 log = setup_logger(__name__)
@@ -84,7 +88,7 @@ class Database:
         return self._parameter_ranges
 
     @property
-    def paramerter_names(self) -> List[str]:
+    def parameter_names(self) -> List[str]:
         return self._parameter_names
 
     @property
@@ -288,7 +292,11 @@ class Database:
 
         with silence_console_log():
 
-            for i in tqdm(range(len(sub_values))):
+            for i in tqdm(
+                range(len(sub_values)),
+                desc="building table model",
+                colour=Colors.YELLOW,
+            ):
 
                 ### DO NOT SORT
 
@@ -303,6 +311,159 @@ class Database:
 
         return TemplateModel(name)
 
+    def check_for_missing_parameters(
+        self, parameter_grid: ParameterGrid, create_new_grid: bool = False
+    ) -> None:
+
+        """Search a parameter grid for missing values
+
+        :param parameter_grid:
+        :type parameter_grid: ParameterGrid
+        :param create_new_grid:
+        :type create_new_grid: bool
+        :returns:
+
+        """
+        missing_parameters = []
+
+        for i in tqdm(
+            range(parameter_grid.n_points),
+            desc="search through parameter grid",
+            colour=Colors.BLUE,
+        ):
+
+            these_parameters = np.atleast_2d(
+                parameter_grid.at_index(i, as_array=True)
+            )
+
+            # see if these parmeters exist!
+
+            if (
+                np.isclose(self._grid_points, these_parameters).all(-1).sum()
+                == 0
+            ):
+
+                log.debug(f"MISSING:{these_parameters[0]}")
+
+                missing_parameters.append(these_parameters[0].tolist())
+
+        if len(missing_parameters) == 0:
+
+            log.info("There are no missing parameters!")
+
+        else:
+
+            log.warning(
+                f"There were {len(missing_parameters)} missing parameters!"
+            )
+
+            if create_new_grid:
+
+                missing_parameters = np.array(missing_parameters)
+
+                log.info("Creating a new grid")
+
+                parameter_list = []
+
+                for i, par_name in enumerate(parameter_grid.parameter_names):
+
+                    par = Parameter(
+                        name=par_name,
+                        custom=True,
+                        values=missing_parameters[:, i],
+                    )
+
+                    parameter_list.append(par)
+
+                new_parameter_grid = ParameterGrid(
+                    parameter_list, parameter_grid.energy_grid
+                )
+
+                new_parameter_grid.write("missing_parameter_grid.yml")
+
+    def _parallel_coord_plot(
+        self,
+        parameter: np.ndarray,
+        colorscale: str = "viridis",
+        as_log: bool = False,
+    ) -> None:
+
+        dims = [
+            dict(label=p, values=v)
+            for p, v in zip(self._parameter_names, self._grid_points.T)
+        ]
+
+        if as_log:
+
+            parameter = np.log10(parameter)
+
+        fig = go.Figure(
+            data=go.Parcoords(
+                line=dict(
+                    color=parameter,
+                    colorscale=colorscale,
+                    showscale=True,
+                    cmin=parameter.min(),
+                    cmax=parameter.max(),
+                ),
+                dimensions=dims,
+                unselected=dict(line=dict(color='white', opacity=0.01)),
+            )
+        )
+
+        fig.show()
+
+    def plot_runtime(self, colorscale: str = "plasma"):
+
+        """
+        show a parallel plot of the run time
+
+        :param colorscale:
+        :type colorscale:
+        :returns:
+
+        """
+        self._parallel_coord_plot(
+            self._run_time, colorscale=colorscale, as_log=True
+        )
+
+    def plot_meta_data(
+        self,
+        meta_number: int = 0,
+        colorscale: str = "plasma",
+        as_log: bool = False,
+    ):
+
+        """
+
+        parallel plot of the meta data
+
+        :param meta_number:
+        :type meta_number: int
+        :param colorscale:
+        :type colorscale: str
+        :param as_log:
+        :type as_log: bool
+        :returns:
+
+        """
+
+        if self._meta_data is not None:
+
+            self._parallel_coord_plot(
+                self._meta_data[f"meta_{meta_number}"],
+                colorscale=colorscale,
+                as_log=as_log,
+            )
+
+        else:
+
+            msg = "This database has no meta data"
+
+            log.error(msg)
+
+            raise RuntimeError(msg)
+
 
 def merge_databases(
     *file_names: List[str], new_name: str = "merged_db.h5"
