@@ -1,4 +1,6 @@
 import json
+import shutil
+import time
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Optional
@@ -6,7 +8,10 @@ from typing import Optional
 import h5py
 import numpy as np
 import yaml
-from omegaconf import OmegaConf, MISSING
+from omegaconf import MISSING, OmegaConf
+from tqdm.auto import tqdm
+
+from ronswanson.utils.color import Colors
 
 from .grids import ParameterGrid
 from .script_generator import (
@@ -45,6 +50,7 @@ class SimulationConfig(JobConfig):
     use_nodes: bool = False
     max_nodes: Optional[int] = None
     linear_execution: bool = False
+    num_meta_parameters: Optional[int] = None
 
 
 ## structure for file
@@ -78,6 +84,7 @@ class YAMLStructure:
     clean: bool = True
     simulation: SimulationConfigStructure = SimulationConfigStructure()
     gather: Optional[GatherConfigStructure] = None
+    num_meta_parameters: Optional[int] = None
 
 
 class SimulationBuilder:
@@ -266,6 +273,8 @@ class SimulationBuilder:
 
             with h5py.File(self._out_file, "w") as f:
 
+                f.attrs["has_been_touched"] = False
+
                 pg = ParameterGrid.from_yaml(self._parameter_file)
 
                 # store the parameter names
@@ -334,6 +343,27 @@ class SimulationBuilder:
                 f"There was already a database: [red]{self._out_file}[/red]"
             )
 
+            with h5py.File(self._out_file, "r") as f:
+
+                has_been_touched = f.attrs["has_been_touched"]
+
+            if not has_been_touched:
+
+                log.warning("the database has not been gathered")
+                log.warning("erasing and starting over")
+
+                Path(self._out_file).unlink()
+
+                time.sleep(2)
+
+                self._initialize_database()
+
+            copy_file_name: str = f"{Path(self._out_file).parent}/{Path(self._out_file).stem}_copy{Path(self._out_file).suffix}"
+
+            log.warning(f"a copy will be made to [blue]{copy_file_name}[\blue]")
+
+            shutil.copy(self._out_file, copy_file_name)
+
             self._check_completed()
 
             with h5py.File(self._out_file, "a") as f:
@@ -435,7 +465,11 @@ class SimulationBuilder:
 
         key_out = {}
 
-        for i in range(self._n_nodes):
+        for i in tqdm(
+            range(self._n_nodes),
+            desc="computing node layout",
+            colour=Colors.RED,
+        ):
 
             output = []
 
@@ -475,8 +509,12 @@ class SimulationBuilder:
             )
             log.debug(f"number iterations: {self._n_iterations}")
 
-            for i in range(
-                self._n_gather_nodes * self._gather_config.n_cores_per_node
+            for i in tqdm(
+                range(
+                    self._n_gather_nodes * self._gather_config.n_cores_per_node
+                ),
+                desc="computing nodes for gather operation",
+                colour=Colors.GREEN,
             ):
 
                 core_list = []
@@ -508,6 +546,7 @@ class SimulationBuilder:
             self._simulation_config.linear_execution,
             self._has_complete_params,
             self._current_database_size,
+            clean=self._clean,
         )
 
         py_gen.write(str(self._base_dir))
